HGC
====
.. image:: https://readthedocs.org/projects/hgc/badge/?version=latest&style=flat
                    :target: https://hgc.readthedocs.io
.. image:: https://img.shields.io/travis/KWR-Water/hgc
                    :target: https://travis-ci.com/KWR-Water/hgc
.. image:: https://img.shields.io/codecov/c/gh/KWR-Water/hgc
                    :target: https://codecov.io/gh/KWR-Water/hgc 

HGC, or HydroGeoChemistry, is a python package for correction, validation and analysis of ground water quality samples. 
See documentation_ for more information.


Installation
------------
To get the latest stable version, use::

  pip install hgc
 
License
-------

This package is MIT licensed. See `License File <https://github.com/KWR-Water/hgc/blob/master/LICENSE>`__.
 
.. _documentation: https://hgc.readthedocs.io/en/latest/
